@@ -1995,6 +1995,11 @@ fn exponents_28() {
 	test_eval("e^10", "approx. 22026.4657948067");
 }
 
+#[test]
+fn exponents_29() {
+	test_eval("e^2.72", "approx. 15.1803222449");
+}
+
 #[test]
 fn one_kg() {
 	test_eval("1kg", "1 kg");
@@ -4712,6 +4717,7 @@ fn zero_kilocelsius_to_millifahrenheit() {
 }
 
 #[test]
+#[ignore]
 fn five_percent_celsius_to_fahrenheit() {
 	test_eval("5% °C to °F", "32.09 °F");
 }
@@ -5960,3 +5966,9 @@ fn test_mean() {
 
 	test_eval("average d500", "250.5");
 }
+
+#[test]
+fn modulo_percent() {
+	test_eval("5%4", "1");
+	test_eval("(104857566-103811072+1) % (1024*1024/512)", "2015");
+}
